'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _defineProperties(target, props) {
  for (var i = 0; i < props.length; i++) {
    var descriptor = props[i];
    descriptor.enumerable = descriptor.enumerable || false;
    descriptor.configurable = true;
    if ("value" in descriptor) descriptor.writable = true;
    Object.defineProperty(target, descriptor.key, descriptor);
  }
}

function _createClass(Constructor, protoProps, staticProps) {
  if (protoProps) _defineProperties(Constructor.prototype, protoProps);
  if (staticProps) _defineProperties(Constructor, staticProps);
  Object.defineProperty(Constructor, "prototype", {
    writable: false
  });
  return Constructor;
}

// Leaving 'd' out to avoid generating the word 'ad'
var defaultAlphabet = 'abcefghijklmnopqrstuvwxyz0123456789_-';
function createIdGenerator(alphabet) {
  var options = {
    alphabet: alphabet || defaultAlphabet,
    length: 1,
    index: 0
  };
  return function () {
    var res = generateId(options); // class names should not start with a number or a dash

    while (/^[0-9-].*$/.test(res)) {
      res = generateId(options);
    }

    return res;
  };
}

var generateId = function generateId(options) {
  var res = '';

  for (var i = options.length - 1; i >= 0; i--) {
    var x = Math.pow(options.alphabet.length, i);
    var n = Math.floor(options.index / x);
    res += options.alphabet[n % options.alphabet.length];
  }

  options.index++;

  if (options.index > Math.pow(options.alphabet.length, options.length) - 1) {
    options.length++;
    options.index = 0;
  }

  return res;
};

var CssShortener = /*#__PURE__*/function () {
  function CssShortener(options) {
    this._map = {};
    this.generateId = createIdGenerator(options == null ? void 0 : options.alphabet);
  }

  var _proto = CssShortener.prototype;

  /**
   * Imports mapped CSS class names
   * @param {object} map Map that should be imported
   * @param {boolean} override If true, existing mappings will be overridden
   */
  _proto.importMap = function importMap(map, override) {
    if (override === void 0) {
      override = false;
    }

    for (var classNameToImport in map) {
      if (this.isAlreadyUsed(map[classNameToImport])) throw new Error("Cannot import class '" + classNameToImport + "'. Short class name '" + map[classNameToImport] + "' is already being used.");

      if (this._map[classNameToImport] != null) {
        // Override mapped class name
        if (override === true) this._map[classNameToImport] = map[classNameToImport];
      } else this._map[classNameToImport] = map[classNameToImport]; // Import class name

    }
  }
  /**
   * Checks if the given class name is already used as a replacement for a longer class name
   * @param className class name to check for
   */
  ;

  _proto.isAlreadyUsed = function isAlreadyUsed(className) {
    return Object.values(this.map).includes(className);
  }
  /**
   * Generates and maps a new class name
   * @param className The existing class name that should be replaced
   * @returns {string} The new generated and mapped class name
   */
  ;

  _proto.shortenClassName = function shortenClassName(className) {
    // Return the already mapped class name
    if (this._map[className] != null) return this._map[className]; // Generate, map and return the new class name

    var newClassName = this.generateId();

    while (this.isAlreadyUsed(newClassName)) {
      newClassName = this.generateId();
    }

    return this._map[className] = newClassName;
  };

  _createClass(CssShortener, [{
    key: "map",
    get: function get() {
      return this._map;
    }
  }]);

  return CssShortener;
}();

exports.CssShortener = CssShortener;
//# sourceMappingURL=css-shortener.cjs.development.js.map
